@@ -9,7 +9,7 @@ use Lemonldap::NG::Portal::Main::Constants qw(
   PE_ERROR
 );
 
-our $VERSION = '2.17.0';
+our $VERSION = '2.18.0';
 
 extends 'Lemonldap::NG::Portal::2F::Register::Base';
 with 'Lemonldap::NG::Portal::Lib::2fDevices';
@@ -71,13 +71,16 @@ sub run {
                 )
               )
             {
-                return $self->p->sendHtml(
-                    $req, 'error',
-                    params => {
-                        RAW_ERROR       => 'yourKeyIsRegistered',
-                        AUTH_ERROR_TYPE => 'positive',
-                    }
-                );
+                $self->markRegistered($req);
+                return [
+                    302,
+                    [
+                        Location => $self->p->buildUrl(
+                            "2fregisters", { continue => 1 }
+                        )
+                    ],
+                    []
+                ];
             }
             else {
                 $self->logger->debug(
