@@ -584,20 +584,21 @@ sub display {
     my ( $self, $req ) = @_;
     $self->logger->debug( 'Display called with code: ' . $req->error );
     my %tplPrm = (
-        SKIN_PATH       => $self->conf->{staticPrefix},
-        SKIN            => $self->p->getSkin($req),
-        SKIN_BG         => $self->conf->{portalSkinBackground},
-        MAIN_LOGO       => $self->conf->{portalMainLogo},
-        AUTH_ERROR      => $req->error,
-        AUTH_ERROR_TYPE => $req->error_type,
-        AUTH_ERROR_ROLE => $req->error_role,
-        AUTH_URL        => $req->data->{_url},
-        CHOICE_VALUE    => $req->{_authChoice},
-        EXPMAILDATE     => $req->data->{expMailDate},
-        EXPMAILTIME     => $req->data->{expMailTime},
-        STARTMAILDATE   => $req->data->{startMailDate},
-        STARTMAILTIME   => $req->data->{startMailTime},
-        MAILALREADYSENT => $req->data->{mailAlreadySent},
+        SKIN_PATH                       => $self->conf->{staticPrefix},
+        SKIN                            => $self->p->getSkin($req),
+        SKIN_BG                         => $self->conf->{portalSkinBackground},
+        MAIN_LOGO                       => $self->conf->{portalMainLogo},
+        AUTH_ERROR                      => $req->error,
+        AUTH_ERROR_TYPE                 => $req->error_type,
+        AUTH_ERROR_ROLE                 => $req->error_role,
+        ( 'AUTH_ERROR_' . $req->error ) => 1,
+        AUTH_URL                        => $req->data->{_url},
+        CHOICE_VALUE                    => $req->{_authChoice},
+        EXPMAILDATE                     => $req->data->{expMailDate},
+        EXPMAILTIME                     => $req->data->{expMailTime},
+        STARTMAILDATE                   => $req->data->{startMailDate},
+        STARTMAILTIME                   => $req->data->{startMailTime},
+        MAILALREADYSENT                 => $req->data->{mailAlreadySent},
         (
             $req->data->{customScript}
             ? ( CUSTOM_SCRIPT => $req->data->{customScript} )
@@ -748,7 +749,7 @@ sub certificateHash {
 
     {
         local $/ = undef;    # Slurp mode
-        open CERT, "$file" or die;
+        open CERT, "<", "$file" or die;
         $cert = <CERT>;
         close CERT;
     }
